{% for field in form %}
<div class="form-group">
	<label for="{{ field.id_for_label }}">{{ field.label }}</label>
	{{ field }}
	{{ field.errors }}
</div>
{% endfor %}
{% csrf_token %}
{{ form.media }}